@@ -16,9 +16,8 @@ use File::Slurper qw (read_text);
 use File::Spec;
 use Readonly;
 use Data::Walk;
-use Try::Tiny;
 
-our $VERSION = 0.09;
+our $VERSION = 0.04;
 
 our $override;
 my $JSON_OBJ = Cpanel::JSON::XS->new()->utf8->pretty();
@@ -35,10 +34,6 @@ Readonly::Hash my %MOCKED_DBI_METHODS => (
 	selectrow_array    => 'DBI::db::selectrow_array',
 	selectrow_arrayref => 'DBI::db::selectrow_arrayref',
 	selectrow_hashref  => 'DBI::db::selectrow_hashref',
-	fetch              => 'DBI::st::fetch',
-	prepare_cached     => 'DBI::db::prepare_cached',
-	prepare            => 'DBI::db::prepare',
-	mocked_prepare     => 'DBD::Mock::db::prepare',
 );
 
 sub new {
@@ -67,12 +62,12 @@ sub _initialize {
 
 	$self->_set_fixtures_file($args_for{file});
 	$self->{override_flag} = 0;
-	$override              = Sub::Override->new();
-	$self->{override}      = $override;
 
 	if (my $dbh = $args_for{dbh}) {
 		$self->{dbh}           = $dbh;
+		$override              = Sub::Override->new();
 		$self->{bind_params}   = [];
+		$self->{override}      = $override;
 		$self->{override_flag} = 1;
 		$self->_override_dbi_methods();
 		$self->{result} = [];
@@ -126,10 +121,6 @@ sub _override_dbi_methods {
 	$self->_override_dbi_selectrow_array($MOCKED_DBI_METHODS{selectrow_array});
 	$self->_override_dbi_selectrow_arrayref($MOCKED_DBI_METHODS{selectrow_arrayref});
 	$self->_override_dbi_selectrow_hashref($MOCKED_DBI_METHODS{selectrow_hashref});
-	$self->_override_dbi_fecth($MOCKED_DBI_METHODS{fetch});
-	$self->_override_dbi_prepare_cached($MOCKED_DBI_METHODS{prepare_cached});
-	$self->_override_dbi_prepare($MOCKED_DBI_METHODS{prepare});
-	$self->_override_dbi_mocked_prepare($MOCKED_DBI_METHODS{mocked_prepare});
 
 	return $self;
 }
@@ -159,7 +150,7 @@ sub restore_all {
 sub _override_dbi_execute {
 	my $self        = shift;
 	my $dbi_execute = shift;
-
+	
 	my $orig_execute = \&$dbi_execute;
 
 	$self->get_override_object()->replace(
@@ -167,17 +158,10 @@ sub _override_dbi_execute {
 		sub {
 			my ($sth, @args) = @_;
 
-			my $sql    = $sth->{Statement};
-			my $retval = $orig_execute->($sth, @args);
+			my $sql = $sth->{Statement};
 
-			my $col_names;
-			try {
-				$col_names = $sth->{NAME}
-					if $sql !~ m/^INSERT|^UPDATE|^DELETE/i;
-			} catch {
-				my $error = $_;
-				say $error;
-			};
+			my $col_names = $sth->{NAME};
+			my $retval    = $orig_execute->($sth, @args);
 
 			my $rows       = $sth->rows();
 			my $query_data = {
@@ -187,8 +171,7 @@ sub _override_dbi_execute {
 			};
 
 			my $result = [];
-			if ($sql =~ m/^INSERT|^UPDATE|^DELETE/i) {
-				push @$result, ['rows'];
+			if ($rows > 0) {
 				foreach my $row (1 .. $rows) {
 					push @{$result}, [];
 				}
@@ -244,7 +227,7 @@ sub _override_dbi_fetchrow_hashref {
 
 			my $retval = $orig_selectrow_hashref->($sth);
 
-			if (ref $retval && !defined $self->{result}->[-1]->{results}) {
+			if (ref $retval) {
 				my $query_results = $self->_set_hashref_response($sth, $retval);
 				push @{$self->{result}->[-1]->{results}}, $query_results;
 				$self->_write_to_file();
@@ -450,8 +433,6 @@ sub _override_dbi_selectrow_array {
 			return @retval;
 		}
 	);
-
-	return $self;
 }
 
 sub _override_dbi_selectrow_arrayref {
@@ -488,8 +469,6 @@ sub _override_dbi_selectrow_arrayref {
 			return $retval;
 		}
 	);
-
-	return $self;
 }
 
 sub _override_dbi_selectrow_hashref {
@@ -519,99 +498,6 @@ sub _override_dbi_selectrow_hashref {
 			return $retval;
 		}
 	);
-
-	return $self;
-}
-
-sub _override_dbi_fecth {
-	my $self  = shift;
-	my $fetch = shift;
-
-	my $original_fetch = \&$fetch;
-	my $result         = [];
-	$self->get_override_object()->replace(
-		$fetch,
-		sub {
-			my ($sth, @args) = @_;
-			my $row = $original_fetch->($sth, @args);
-			if (ref $row) {
-				my @shallow_copy = @{$row};
-				if ($sth->{Statement} =~ /WHERE/i && $sth->{Statement} !~ /ORDER BY/i) {
-					unshift @{$self->{result}->[-1]->{results}}, \@shallow_copy;
-				} else {
-					push @{$self->{result}->[-1]->{results}}, \@shallow_copy;
-				}
-				$self->_write_to_file();
-			}
-
-
-			return $row;
-		}
-	);
-
-	return $self;
-}
-
-sub _override_dbi_prepare_cached {
-	my $self           = shift;
-	my $prepare_cached = shift;
-
-	my $original_prepare_cached = \&$prepare_cached;
-	$self->get_override_object()->replace(
-		$prepare_cached,
-		sub {
-			my ($dbh, $sql, $attr, $if_active) = @_;
-
-			$sql = $self->_normalize_sql($sql);
-			return $original_prepare_cached->($dbh, $sql, $attr, $if_active);
-		}
-	);
-	return $self;
-}
-
-sub _override_dbi_prepare {
-	my $self    = shift;
-	my $prepare = shift;
-
-	my $original_prepare = \&$prepare;
-	$self->get_override_object()->replace(
-		$prepare,
-		sub {
-			my ($dbh, $sql, $attr) = @_;
-
-			$sql = $self->_normalize_sql($sql);
-			return $original_prepare->($dbh, $sql, $attr);
-		}
-	);
-
-	return $self;
-}
-
-sub _override_dbi_mocked_prepare {
-	my $self           = shift;
-	my $mocked_prepare = shift;
-
-	my $original_mocked_prepare = \&$mocked_prepare;
-	$self->get_override_object()->replace(
-		$mocked_prepare,
-		sub {
-			my ($dbh, $sql) = @_;
-
-			$sql = $self->_normalize_sql($sql);
-			return $original_mocked_prepare->($dbh, $sql);
-		}
-	);
-
-	return $self;
-}
-
-sub _normalize_sql {
-	my ($self, $sql) = @_;
-
-	$sql =~ s/\s+/ /g;
-	$sql =~ s/^\s+|\s+$//g;
-
-	return $sql;
 }
 
 sub _get_current_record_column_names {
@@ -727,7 +613,7 @@ sub DESTROY {
 
 =head1 NAME
 
-DBD::Mock::Session::GenerateFixtures - A module to generate fixtures for DBD::Mock::Session
+DBD::Mock::Session::GenerateFixtures
 
 =head1 SYNOPSIS
 
@@ -751,26 +637,6 @@ DBD::Mock::Session::GenerateFixtures - A module to generate fixtures for DBD::Mo
 	my $dbh = $mock_dumper->get_dbh();
 	# Your code using the mock DBD
 
-	# or with Rose::DB
-
-	my $mock_dumper = DBD::Mock::Session::GenerateFixtures->new();
-
-	my $override = Sub::Override->new();
-	my $dbh      = $mock_dumper->get_dbh();
-	$dbh->{mock_start_insert_id} = 3;
-
-	$override->replace('Rose::DB::dbh' => sub {return $dbh});
-	$override->inject('DBD::Mock::db::last_insert_rowid', sub {$dbh->{mock_last_insert_id}});
-
-	my $num_rows_updated = DB::Media::Manager->update_media(
-		set => {
-			location => '/data/music/claire_de_lune.ogg',
-		},
-		where => [
-			id => 2,
-		],
-	);
-
 =head1 DESCRIPTION
 
 When a real DBI database handle ($dbh) is provided, the module generates C<DBD::Mock::Session> data and stores it in a JSON file. 
@@ -872,34 +738,6 @@ Overrides the C<selectrow_arrayref> method of C<DBI::db> in order to capture the
 
 Overrides the C<selectrow_hashref> method of C<DBI::db> in order to capture the rows returned.
 
-=head2 _override_dbi_fecth($sth, @args)
-
-Overrides the C<fetch> method of C<DBI::st>
-
-=head2 _override_dbi_prepare
-
-  _override_dbi_prepare($prepare);
-
-  This method overrides the `DBI::db::prepare` method. It customizes how SQL statements are prepared for execution
-
-=head2 _override_dbi_prepare_cached
-
-	_override_dbi_prepare_cached($prepare_cached);
-
-	This method overrides the `DBI::db::prepare_cached` method. It provides a mechanism for caching prepared statements to optimize repeated queries.
-
-=head2 _override_dbi_mocked_prepare
-
-	_override_dbi_mocked_prepare($mocked_prepare);
-
-	This method overrides the `DBD::Mock::db::prepare` method. It is used for testing purposes to mock the behavior of statement preparation.
-
-=head2 _normalize_sql
-
-	_normalize_sql($sql);
-
-	This method normalizes an SQL query string by removing extra whitespace and trimming leading or trailing spaces.
-
 =head2 _get_current_record_column_names()
 
 Returns the column names of the current record being processed.
